Module prelude

Module prelude 

Re-exports

pub use flarrow_api;
pub use flarrow_builtins;
pub use flarrow_file_ext;
pub use flarrow_flows;
pub use flarrow_url_scheme;

Modules

flarrow_api
flarrow_file_ext
flarrow_layout
flarrow_message
flarrow_runtime_core
thirdparty

Structs

DataflowLayout
Represents a flattened dataflow layout
DataflowMessage
Dataflow message. Cheap to clone
DefaultFileExtPlugin
DefaultUrlSchemePlugin
DynamicallyLinkedFileExtPlugin
DynamicallyLinkedNode
DynamicallyLinkedUrlSchemePlugin
FileExtManager
FileExtManagerBuilder
Flows
Represents the collection of flows in the system (all the MPSC channels)
FlowsBuilder
This is the builder struct available for the user closure when creating flows.
Header
Header for a dataflow message
Input
Typed Input to receive data from the dataflow
InputLayout
Represents an input
Inputs
Inputs let you manage input connections during a node implementation
NodeIOBuilder
This is the object passed to the user’s lambda function to build the node’s IO layout
NodeLayout
Represents a node
NodeLoader
Loader struct passed to the user closure to load nodes
Output
Typed Output to receive data from the dataflow
OutputLayout
Represents an output
Outputs
Outputs let you manage output connections during a node implementation
Printer
Simple sink node that just prints its input to stdout.
Queries
Queries let you manage query connections during a node implementation
Query
Typed Query to query data from the dataflow
QueryLayout
Represents a query
Queryable
Typed Queryable to queryable data to the dataflow
QueryableLayout
Represents a queryable
Queryables
Queryables let you manage queryable connections during a node implementation
RawInput
Not typed Input to receive data from the dataflow
RawOutput
Not typed Output to receive data from the dataflow
RawQuery
Not typed Query to receive data from the dataflow
RawQueryable
Not typed Queryable to receive data from the dataflow
Runtime
Create a new runtime instance.
Timer
Simple source node that emits a “tick” message at a specified frequency.
Transport
Simple operator that does nothing, it just passes its input to its output.
UrlSchemeManager
UrlSchemeManagerBuilder

Enums

Builtin
Enumeration of built-in nodes.
IOLayout
Represents a kind of IO (Input, Output, Query, Queryable)
RuntimeFileExt
RuntimeNode
RuntimeUrlScheme

Traits

ArrowMessage
Trait to represent a message that can be converted to and from an Arrow array.
FileExtPlugin
Node
UrlSchemePlugin

Functions

extract_union_data
Helper function to extract data from a union array.
get_union_fields
Helper function to get the union fields of a message.
make_union_array
Helper function to create a union array.
make_union_fields
Helper function to create a union field.
new_builtin
Creates a new instance of a StaticallyLinked RuntimeNode from a Builtin enum.
unpack_union
Helper function to unpack a union array.

Type Aliases

DynamicallyLinkedFileExtPluginInstance
DynamicallyLinkedNodeInstance
DynamicallyLinkedUrlSchemePluginInstance
MessageReceiver
MPSC Message receiver. Cannot be cloned
MessageSender
MPSC Message sender. Can be cloned, cheap to clone

Attribute Macros

file_ext_plugin
node
url_scheme_plugin

Derive Macros

ArrowMessage
FileExtPlugin
Node
UrlSchemePlugin