Re-exports
pub use flarrow_api;pub use flarrow_builtins;pub use flarrow_file_ext;pub use flarrow_flows;pub use flarrow_url_scheme;
Modules
Structs
- Dataflow
Layout - Represents a flattened dataflow layout
- Dataflow
Message - Dataflow message. Cheap to clone
- Default
File ExtPlugin - Default
UrlScheme Plugin - Dynamically
Linked File ExtPlugin - Dynamically
Linked Node - Dynamically
Linked UrlScheme Plugin - File
ExtManager - File
ExtManager Builder - Flows
- Represents the collection of flows in the system (all the MPSC channels)
- Flows
Builder - This is the builder struct available for the user closure when creating flows.
- Header
- Header for a dataflow message
- Input
- Typed Input to receive data from the dataflow
- Input
Layout - Represents an input
- Inputs
- Inputs let you manage input connections during a node implementation
- NodeIO
Builder - This is the object passed to the user’s lambda function to build the node’s IO layout
- Node
Layout - Represents a node
- Node
Loader - Loader struct passed to the user closure to load nodes
- Output
- Typed Output to receive data from the dataflow
- Output
Layout - Represents an output
- Outputs
- Outputs let you manage output connections during a node implementation
- Printer
- Simple sink node that just prints its input to stdout.
- Queries
- Queries let you manage query connections during a node implementation
- Query
- Typed Query to query data from the dataflow
- Query
Layout - Represents a query
- Queryable
- Typed Queryable to queryable data to the dataflow
- Queryable
Layout - Represents a queryable
- Queryables
- Queryables let you manage queryable connections during a node implementation
- RawInput
- Not typed Input to receive data from the dataflow
- RawOutput
- Not typed Output to receive data from the dataflow
- RawQuery
- Not typed Query to receive data from the dataflow
- RawQueryable
- Not typed Queryable to receive data from the dataflow
- Runtime
- Create a new runtime instance.
- Timer
- Simple source node that emits a “tick” message at a specified frequency.
- Transport
- Simple operator that does nothing, it just passes its input to its output.
- UrlScheme
Manager - UrlScheme
Manager Builder
Enums
- Builtin
- Enumeration of built-in nodes.
- IOLayout
- Represents a kind of IO (Input, Output, Query, Queryable)
- Runtime
File Ext - Runtime
Node - Runtime
UrlScheme
Traits
- Arrow
Message - Trait to represent a message that can be converted to and from an Arrow array.
- File
ExtPlugin - Node
- UrlScheme
Plugin
Functions
- extract_
union_ data - Helper function to extract data from a union array.
- get_
union_ fields - Helper function to get the union fields of a message.
- make_
union_ array - Helper function to create a union array.
- make_
union_ fields - Helper function to create a union field.
- new_
builtin - Creates a new instance of a StaticallyLinked RuntimeNode from a Builtin enum.
- unpack_
union - Helper function to unpack a union array.
Type Aliases
- Dynamically
Linked File ExtPlugin Instance - Dynamically
Linked Node Instance - Dynamically
Linked UrlScheme Plugin Instance - Message
Receiver - MPSC Message receiver. Cannot be cloned
- Message
Sender - MPSC Message sender. Can be cloned, cheap to clone