Module prelude

Modules

arrow_array
The central type in Apache Arrow are arrays, which are a known-length sequence of values all having the same type. This crate provides concrete implementations of each type, as well as an Array trait that can be used for type-erasure.
arrow_data
Low-level array data abstractions for Apache Arrow Rust
arrow_schema
Arrow logical types
eyre
This library provides eyre::Report, a trait object based error handling type for easy idiomatic error handling and reporting in Rust applications.
serde_yml
Serde YML (a fork of Serde YAML)
tokio
A runtime for writing reliable network applications without compromising speed.

Structs

Connector
DataflowLayout
DataflowMessage
DataflowRuntime
DynamicallyLinkedNode
DynamicallyLinkedUrlPlugin
Flows
Header
Input
InputID
Inputs
Loader
NodeID
NodeIO
Output
OutputID
Outputs
RawInput
RawOutput
UrlDefaultPlugin

Enums

NodeResult
RuntimeNode
RuntimeUrlPlugin

Traits

ArrowMessage
Context
Provides the wrap_err method for Result.
Node
OptionExt
Provides the ok_or_eyre method for Option.
UrlPlugin

Functions

extract_union_data
get_union_fields
make_union_array
make_union_fields
unpack_union

Type Aliases

ArrowResult
DynamicallyLinkedNodeInstance
DynamicallyLinkedUrlPluginInstance
NodeNewResult
NodeStartResult
Result
type alias for Result<T, Report>

Attribute Macros

node

Derive Macros

ArrowMessage
Node