Modules
- arrow_
array - The central type in Apache Arrow are arrays, which are a known-length sequence of values
all having the same type. This crate provides concrete implementations of each type, as
well as an
Arraytrait that can be used for type-erasure. - arrow_
data - Low-level array data abstractions for Apache Arrow Rust
- arrow_
schema - Arrow logical types
- eyre
- This library provides
eyre::Report, a trait object based error handling type for easy idiomatic error handling and reporting in Rust applications. - serde_
yml - Serde YML (a fork of Serde YAML)
- tokio
- A runtime for writing reliable network applications without compromising speed.
Structs
- Connector
- Dataflow
Layout - Dataflow
Message - Dataflow
Runtime - Dynamically
Linked Node - Dynamically
Linked UrlPlugin - Flows
- Header
- Input
- InputID
- Inputs
- Loader
- NodeID
- NodeIO
- Output
- OutputID
- Outputs
- RawInput
- RawOutput
- UrlDefault
Plugin
Enums
Traits
- Arrow
Message - Context
- Provides the
wrap_errmethod forResult. - Node
- Option
Ext - Provides the
ok_or_eyremethod forOption. - UrlPlugin
Functions
Type Aliases
- Arrow
Result - Dynamically
Linked Node Instance - Dynamically
Linked UrlPlugin Instance - Node
NewResult - Node
Start Result - Result
- type alias for
Result<T, Report>